| Title: | Diagnosis of Metabolic Dysfunction Associated Fatty Liver Disease |
|---|---|
| Description: | The latest guidelines proposed by International Expert Consensus are used for the clinical diagnosis of Metabolic Associated Fatty Liver Disease (MAFLD). The new definition takes hepatic steatosis (determined by elastography or histology or biomarker-based fatty liver index) as a major criterion. In addition, race, gender, body mass index (BMI), waist circumference (WC), fasting plasma glucose (FPG), systolic blood pressure (SBP), diastolic blood pressure (DBP), triglycerides (TG), high-density lipoprotein cholesterol (HDLC), homeostatic model assessment of insulin resistance (HOMAIR), high sensitive c-reactive protein (HsCRP) for the diagnosis of MAFLD. Each parameter has to be interpreted based on the proposed cut-offs, making the diagnosis slightly complex and error-prone. This package is developed by incorporating the latest international expert consensus guidelines, and it will aid in the easy and quick diagnosis of MAFLD based on FibroScan in busy healthcare settings and also for research purposes. The new definition for MAFLD as per the International Consensus Statement is described by Eslam M et al (2020). <doi:10.1016/j.jhep.2020.03.039>. |
| Authors: | Jagadish Ramasamy [aut, cre] (ORCID: <https://orcid.org/0000-0003-4725-3227>) |
| Maintainer: | Jagadish Ramasamy <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 4.0.0 |
| Built: | 2026-05-26 07:43:04 UTC |
| Source: | https://github.com/jagadishramasamy/mafld |
The latest guidelines proposed by International Expert Consensus are used widely for the clinical diagnosis of Metabolic Associated Fatty Liver Disease (MAFLD). The new definition takes hepatic steatosis (determined by elastography or histology or biomarker-based fatty liver index) as a major criterion. In addition, race, gender, body mass index (BMI), waist circumference (WC), fasting plasma glucose (FPG), systolic blood pressure (SBP), diastolic blood pressure (DBP), triglycerides (TG), high-density lipoprotein cholesterol (HDLC), homeostatic model assessment of insulin resistance (HOMAIR), high sensitive c-reactive protein (HsCRP) for the diagnosis of MAFLD. Each parameter has to be interpreted based on the proposed cut-offs, making the diagnosis slightly complex and error-prone. This package is developed by incorporating the latest international expert consensus guidelines, and it will aid in the easy and quick diagnosis of MAFLD based on FibroScan in busy healthcare settings and also for research purposes. The new definition for MAFLD as per the International Consensus Statement is described by Eslam M et al (2020). <doi:10.1016/j.jhep.2020.03.039>.
MAFLD(x)MAFLD(x)
x |
a data frame with column names as exactly specified. |
Yes or No
MAFLD(x)MAFLD(x)
A data frame with exact column names as specified
xx
A data frame with parameters needed to diagnose MAFLD:
Controlled Attenuation Parameter in dB/m
Body mass index in kg/m2
either Caucasians or Asians
Gender in Male or Female
Waist Circumference in cm
Fasting plasma glucose in mg/dL
Glycated Hemoglobin (in%)
Systolic BP in mm Hg
Diastolic BP in mm Hg
High Density Lipoprotein Cholesterol in mg/dL
Triglycerides in mg/dL
Homeostatis Model Assessment of Inuslin Resistance
High Sensitive C reative Protein
Gamma Glutamyl transferase, IU/L